@@ -12,14 +12,14 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License
-along with notmuch.  If not, see <http://www.gnu.org/licenses/>.
+along with xapers.  If not, see <http://www.gnu.org/licenses/>.
 
-Copyright 2012
+Copyright 2012-2017
 Jameson Rollins <jrollins@finestructure.net>
 """
 
-from database import Database
-from database import DatabaseError
-from database import DatabaseUninitializedError
-from database import DatabaseLockError
-from documents import Documents, Document
+from .database import Database
+from .database import DatabaseError
+from .database import DatabaseUninitializedError
+from .database import DatabaseLockError
+from .documents import Documents, Document
