@@ -24,7 +24,7 @@ import subprocess
 import collections
 
 from ..cli import initdb
-from ..database import DatabaseLockError
+from ..database import DatabaseLockError, DatabaseModifiedError
 
 PALETTE = [
     ('head', 'dark blue, bold', ''),
@@ -102,7 +102,7 @@ class DocItem(urwid.WidgetWrap):
 
         bibdata = doc.get_bibdata()
         if bibdata:
-            for field, value in bibdata.iteritems():
+            for field, value in bibdata.items():
                 if 'title' == field:
                     field_data[field] = value
                 elif 'authors' == field:
@@ -374,7 +374,10 @@ class Search(urwid.Frame):
         return self.__sort[0]
 
     def __set_search(self):
-        count = self.ui.db.count(self.query)
+        try:
+            count = self.ui.db.count(self.query)
+        except DatabaseModifiedError:
+            self.ui.db.reopen()
         if count == 0:
             self.ui.set_status('No documents found.')
             docs = []
@@ -417,7 +420,7 @@ class Search(urwid.Frame):
     def help(self):
         lines = []
         def get_keys(o):
-            for k, cmd in o.keys.items():
+            for k, cmd in list(o.keys.items()):
                 yield (k, str(getattr(getattr(o, cmd), '__doc__')))
         yield (None, "Document commands:")
         for o in get_keys(DocItem):
