@@ -1,9 +1,8 @@
 # declare prerequisites for external binaries used in tests
-test_declare_external_prereq python
-test_declare_external_prereq python2
+test_declare_external_prereq python3
 
-export PATH="$TEST_DIRECTORY"/../bin:$PATH
 export PYTHONPATH="$TEST_DIRECTORY"/../lib:$PYTHONPATH
+alias xapers="python3 -m xapers"
 
 export DOC_DIR="$TEST_DIRECTORY/docs"
 
